.. _sdv.lite.tabular:

.. currentmodule:: sdv.lite.tabular

TabularPreset
=============

.. autosummary::
   :toctree: api/

   TabularPreset
   TabularPreset.list_available_presets
   TabularPreset.fit
   TabularPreset.sample
   TabularPreset.sample_conditions
   TabularPreset.sample_remaining_columns
   TabularPreset.save
   TabularPreset.load
